pub struct PluginSelectionArgs {
pub include_high_cost: bool,
pub exclude_high_cost: bool,
pub enable_plugins: Vec<String>,
pub disable_plugins: Vec<String>,
}Expand description
Plugin-selection controls shared by indexing and selected read paths.
Fields
include_high_cost: boolEnable all high-cost plugins.
High-cost plugins are those classified as high_wall_clock in the
shared plugin registry.
exclude_high_cost: boolExclude all high-cost plugins.
This is mainly useful to override SQRY_INCLUDE_HIGH_COST=1.
enable_plugins: Vec<String>Force-enable a plugin by id.
Repeat this flag to enable multiple plugins. Explicit enable beats the global high-cost mode unless the same plugin is also explicitly disabled.
disable_plugins: Vec<String>Force-disable a plugin by id.
Repeat this flag to disable multiple plugins. Explicit disable wins over explicit enable and global high-cost mode.