pub fn run_batch(
cli: &Cli,
path: &str,
queries_path: &Path,
output: BatchFormat,
output_file: Option<&Path>,
continue_on_error: bool,
stats: bool,
sequential: bool,
) -> Result<()>Expand description
Run the batch command using the provided CLI configuration.
Errors
Returns an error if queries cannot be loaded, the index is missing, or any query execution fails.