pub fn run_config_init(path: Option<&str>, force: bool) -> Result<()>Expand description
Initialize a new config file with defaults.
Errors
Returns an error if the config store cannot be created, validation fails, or the config cannot be initialized.