try_auto_start_daemon

Function try_auto_start_daemon 

pub fn try_auto_start_daemon() -> Result<bool>
Check whether the daemon auto-start opt-in is active, and if so, try to start the daemon.

Returns true if a daemon is now running (either was already running or was successfully started), false if auto-start is disabled (SQRY_DAEMON_AUTO_START is not set to "1").

Not wired into query commands until Task 13. Exported here so Task 13 can use sqry_cli::commands::daemon::try_auto_start_daemon without moving code.

Errors

Propagates errors from [resolve_sqryd_binary] and std::process::Command::status. Errors during the binary execution are treated as a failed auto-start (returns Ok(false) after logging a warning).