History management command implementation
Handles the sqry history subcommand for managing query history.
Functions
- run_
history - Run the history command.
History management command implementation
Handles the sqry history subcommand for managing query history.