Insights command implementation
Provides CLI interface for viewing usage insights and managing local diagnostics data.
Functions
- run_
insights - Run the insights command.
Insights command implementation
Provides CLI interface for viewing usage insights and managing local diagnostics data.