pub struct DisplaySymbol {
pub name: String,
pub qualified_name: String,
pub kind: String,
pub file_path: PathBuf,
pub start_line: usize,
pub start_column: usize,
pub end_line: usize,
pub end_column: usize,
pub metadata: HashMap<String, String>,
pub caller_identity: Option<CallIdentityMetadata>,
pub callee_identity: Option<CallIdentityMetadata>,
}Expand description
Display data for a symbol, constructed directly from graph queries.
This replaces the legacy Symbol wrapper, holding all display data
as owned values without depending on the deprecated Symbol type.
Fields
name: StringSymbol name
qualified_name: StringFully qualified name
kind: StringSymbol kind as string (e.g., “function”, “class”)
file_path: PathBufFull file path
start_line: usizeStart line (1-based)
start_column: usizeStart column (0-based)
end_line: usizeEnd line (1-based)
end_column: usizeEnd column (0-based)
metadata: HashMap<String, String>Additional metadata
caller_identity: Option<CallIdentityMetadata>Caller identity for relation queries
callee_identity: Option<CallIdentityMetadata>Callee identity for relation queries
Implementations
Sourceimpl DisplaySymbol
impl DisplaySymbol
Sourcepub fn from_query_match(m: &QueryMatch<'_>) -> Self
pub fn from_query_match(m: &QueryMatch<'_>) -> Self
Create a DisplaySymbol from a QueryMatch.
Sourcepub fn with_caller_identity(
self,
identity: Option<CallIdentityMetadata>,
) -> Self
pub fn with_caller_identity( self, identity: Option<CallIdentityMetadata>, ) -> Self
Create with caller identity for relation queries.
Sourcepub fn with_callee_identity(
self,
identity: Option<CallIdentityMetadata>,
) -> Self
pub fn with_callee_identity( self, identity: Option<CallIdentityMetadata>, ) -> Self
Create with callee identity for relation queries.
Sourcepub fn kind_string(&self) -> &str
pub fn kind_string(&self) -> &str
Get the symbol kind as a string.