pub struct TextFormatter { /* private fields */ }Expand description
Text formatter for human-readable output
Implementations
Sourceimpl TextFormatter
impl TextFormatter
Sourcepub fn new(
use_color: bool,
display_mode: NameDisplayMode,
theme: ThemeName,
) -> Self
pub fn new( use_color: bool, display_mode: NameDisplayMode, theme: ThemeName, ) -> Self
Create new text formatter
Sourcepub fn with_preview(
self,
config: PreviewConfig,
workspace_root: PathBuf,
) -> Self
pub fn with_preview( self, config: PreviewConfig, workspace_root: PathBuf, ) -> Self
Enable preview rendering with the given configuration and workspace root
Sourcepub fn format_workspace(
&self,
symbols: &[NodeWithRepo],
streams: &mut OutputStreams,
) -> Result<()>
pub fn format_workspace( &self, symbols: &[NodeWithRepo], streams: &mut OutputStreams, ) -> Result<()>
Format workspace results that include repository metadata. P2-3 Step 2e: Text formatting is display/logging code - deprecated accessors allowed
Errors
Returns an error if writing to the output streams fails.