pub fn global_config_dir() -> Result<PathBuf>
Get the default global config directory.
This is a convenience function for when you don’t have a full config.
Returns an error if the config directory cannot be determined.