open_shared_index

Function open_shared_index 

pub fn open_shared_index(
    project_root: Option<&Path>,
    config: PersistenceConfig,
) -> Result<Arc<UserMetadataIndex>>
Create a shared user metadata index.

This is the recommended way to create an index for use across components.

Errors

Returns an error if the index cannot be opened.