Module impact

Module impact 

Impact command implementation

Provides CLI interface for analyzing what would break if a symbol changes.

Constants

AMBIGUOUS_SYMBOL_ERROR_CODE
Stable error code for the sqry::ambiguous_symbol envelope.
AMBIGUOUS_SYMBOL_EXIT_CODE
Stable CLI exit code surfaced when a symbol resolution is ambiguous.
SYMBOL_NOT_FOUND_ERROR_CODE
Stable error code for the sqry::symbol_not_found envelope.
SYMBOL_NOT_FOUND_EXIT_CODE
Stable CLI exit code surfaced when a symbol cannot be located in the graph.

Functions

run_impact
Run the impact command.