Impact command implementation
Provides CLI interface for analyzing what would break if a symbol changes.
Constants
- AMBIGUOUS_
SYMBOL_ ERROR_ CODE - Stable error code for the
sqry::ambiguous_symbolenvelope. - AMBIGUOUS_
SYMBOL_ EXIT_ CODE - Stable CLI exit code surfaced when a symbol resolution is ambiguous.
- SYMBOL_
NOT_ FOUND_ ERROR_ CODE - Stable error code for the
sqry::symbol_not_foundenvelope. - SYMBOL_
NOT_ FOUND_ EXIT_ CODE - Stable CLI exit code surfaced when a symbol cannot be located in the graph.
Functions
- run_
impact - Run the impact command.