pub fn open_shared_index(
project_root: Option<&Path>,
config: PersistenceConfig,
) -> Result<Arc<UserMetadataIndex>>Expand description
Create a shared user metadata index.
This is the recommended way to create an index for use across components.
Errors
Returns an error if the index cannot be opened.